import { Injectable } from "@nestjs/common";
import { TrpcService } from "@server/trpc/trpc.service";
import { SportStandardService } from "./sportStandard.service";
import { z, ZodType } from "zod";
import { Prisma } from "@nice/common";

const SportStandardArgsSchema:ZodType<Prisma.SportStandardCreateArgs> = z.any()
const SportStandardUpdateArgsSchema:ZodType<Prisma.SportStandardUpdateArgs> = z.any()
const SportStandardFindManyArgsSchema:ZodType<Prisma.SportStandardFindManyArgs> = z.any()
@Injectable()
export class SportStandardRouter {
    constructor(
        private readonly trpc: TrpcService,
        private readonly sportStandardService: SportStandardService,
    ) { }

    router = this.trpc.router({
        create:this.trpc.procedure.input(SportStandardArgsSchema)
            .mutation(async ({input})=>{
                return this.sportStandardService.create(input)
            }),
        update:this.trpc.procedure.input(SportStandardUpdateArgsSchema)
            .mutation(async ({input})=>{
                return this.sportStandardService.update(input)
            }),
        findMany:this.trpc.procedure.input(SportStandardFindManyArgsSchema)
            .query(async ({input})=>{
                return this.sportStandardService.findMany(input)
            })
    })

}